@@ -3,7 +3,7 @@
 ;; Author:       Mats Lidell <matsl@gnu.org>
 ;;
 ;; Orig-Date:    28-Feb-21 at 23:26:00
-;; Last-Mod:     18-Oct-25 at 12:43:56 by Bob Weiner
+;; Last-Mod:     17-Nov-25 at 16:40:58 by Mats Lidell
 ;;
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
@@ -126,6 +126,20 @@
     (goto-char 7)
     (should (not (hpath:at-p)))))
 
+(ert-deftest hpath:path-at-point-with-unbalanced-quote-on-same-line ()
+  "Verify `hpath:at-p' behavior when there is an unbalanced quotes on same line."
+  (dolist (v '(("  \"/tmp\"  "  . t)
+               ("  \"/tmp\" \"" . t)
+               ("\" \"/tmp\"  " . nil)))
+    (let ((text (car v))
+          (find (cdr v)))
+      (with-temp-buffer
+        (insert (format "%s\n" v))
+        (goto-char 6)
+        (if find
+            (should (string= (hpath:at-p nil t) "/tmp"))
+          (should-not (hpath:at-p nil t)))))))
+
 (ert-deftest hpath:find-exec-shell-cmd-test ()
   "Path prefix ! will run pathname as a non windowed program."
   (let ((was-called nil))
@@ -392,7 +406,7 @@ See `hpath:line-and-column-regexp'."
   (should-not (string-match hpath:line-and-column-regexp "/foo/bar.org:LL1"))
   (should-not (string-match hpath:line-and-column-regexp "/foo/bar.org:C1")))
 
-(ert-deftest hpath--hpath:delimited-possible-path ()
+(ert-deftest hpath--hpath:delimited-possible-path-in-ls-R ()
   "Verify delimited paths are found in an `ls -R' listing in `shell-mode'."
   (let ((files
          '(("file1.ext file2.ext file3.ext"                   ; Space delimited
@@ -442,6 +456,32 @@ dir/subdir:
               (should (string= (expand-file-name (concat filename ".ext") "dir/subdir")
                                (hpath:delimited-possible-path))))))))))
 
+(ert-deftest hpath--hpath:delimited-possible-path ()
+  "Verify hpath:delimited-possible-path."
+  ;;              text   result mode
+  (let ((paths '(("/tmp" "/tmp" text-mode)
+                 ("/does-not-exist" "/does-not-exist" text-mode)
+                 ("file://file " "file" text-mode)
+                 ("&quot;'file'&quote" "file" text-mode)
+                 ("\\\"'file'\\\"" "file" text-mode)
+                 ("@file{file}" "file" text-mode)
+                 ("\"file\"" "file" text-mode)
+                 ("\"'file'\"" "file" text-mode)
+                 ("\"`file'\"" "file" text-mode)
+                 ("'file'" "file" python-mode)
+                 ("'''file'''" "file" python-mode)
+                 ("``file''" "file" texinfo-mode))))
+    (dolist (path paths)
+      (let ((text (nth 0 path))
+            (result (nth 1 path))
+            (mode (nth 2 path)))
+        (ert-info ((format "Find path %s in mode: %s" text mode))
+          (with-temp-buffer
+            (funcall mode)
+            (insert (format "%s\n" text))
+            (goto-char (/ (length text) 2))
+            (should (string= result (hpath:delimited-possible-path)))))))))
+
 (ert-deftest hpath--to-markup-anchor ()
   "Verify `hpath:to-markup-anchor'."
   (dolist (v '((text-mode 2) (outline-mode 0)))
